@@ -68,7 +68,7 @@ echoes following the method described in [@posse_t2s].
 The optimally combined time series was carried forward as the *preprocessed BOLD*.
 """
 
-    inputnode = pe.Node(niu.IdentityInterface(fields=["bold_file"]), name="inputnode")
+    inputnode = pe.Node(niu.IdentityInterface(fields=["bold_file", "bold_mask"]), name="inputnode")
 
     outputnode = pe.Node(niu.IdentityInterface(fields=["bold"]), name="outputnode")
 
@@ -78,7 +78,8 @@ The optimally combined time series was carried forward as the *preprocessed BOLD
 
     # fmt: off
     workflow.connect([
-        (inputnode, t2smap_node, [('bold_file', 'in_files')]),
+        (inputnode, t2smap_node, [('bold_file', 'in_files'),
+                                  ('bold_mask', 'mask_file')]),
         (t2smap_node, outputnode, [('optimal_comb', 'bold')]),
     ])
     # fmt: on
